# coding: utf-8

# flake8: noqa

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.130.0"

# import apis into sdk package
from printnanny_api_client.api.accounts_api import AccountsApi
from printnanny_api_client.api.achievements_api import AchievementsApi
from printnanny_api_client.api.alerts_api import AlertsApi
from printnanny_api_client.api.crash_reports_api import CrashReportsApi
from printnanny_api_client.api.devices_api import DevicesApi
from printnanny_api_client.api.janus_api import JanusApi
from printnanny_api_client.api.moonraker_api import MoonrakerApi
from printnanny_api_client.api.octoprint_api import OctoprintApi
from printnanny_api_client.api.schema_api import SchemaApi
from printnanny_api_client.api.settings_api import SettingsApi
from printnanny_api_client.api.shop_api import ShopApi
from printnanny_api_client.api.videos_api import VideosApi

# import ApiClient
from printnanny_api_client.api_client import ApiClient
from printnanny_api_client.configuration import Configuration
from printnanny_api_client.exceptions import OpenApiException
from printnanny_api_client.exceptions import ApiTypeError
from printnanny_api_client.exceptions import ApiValueError
from printnanny_api_client.exceptions import ApiKeyError
from printnanny_api_client.exceptions import ApiAttributeError
from printnanny_api_client.exceptions import ApiException
# import models into sdk package
from printnanny_api_client.models.achievement import Achievement
from printnanny_api_client.models.achievement_type_enum import AchievementTypeEnum
from printnanny_api_client.models.callback_token_auth import CallbackTokenAuth
from printnanny_api_client.models.callback_token_auth_request import CallbackTokenAuthRequest
from printnanny_api_client.models.crash_report import CrashReport
from printnanny_api_client.models.crash_report_status_enum import CrashReportStatusEnum
from printnanny_api_client.models.dj_stripe_charge import DjStripeCharge
from printnanny_api_client.models.dj_stripe_checkout_session import DjStripeCheckoutSession
from printnanny_api_client.models.dj_stripe_customer import DjStripeCustomer
from printnanny_api_client.models.dj_stripe_payment_intent import DjStripePaymentIntent
from printnanny_api_client.models.dj_stripe_price import DjStripePrice
from printnanny_api_client.models.dj_stripe_product import DjStripeProduct
from printnanny_api_client.models.email_alert_settings import EmailAlertSettings
from printnanny_api_client.models.email_alert_settings_request import EmailAlertSettingsRequest
from printnanny_api_client.models.email_auth import EmailAuth
from printnanny_api_client.models.email_auth_request import EmailAuthRequest
from printnanny_api_client.models.email_waitlist import EmailWaitlist
from printnanny_api_client.models.email_waitlist_request import EmailWaitlistRequest
from printnanny_api_client.models.error_detail import ErrorDetail
from printnanny_api_client.models.event_source_enum import EventSourceEnum
from printnanny_api_client.models.event_type_enum import EventTypeEnum
from printnanny_api_client.models.event_types_enum import EventTypesEnum
from printnanny_api_client.models.gcode_file import GcodeFile
from printnanny_api_client.models.janus_config_type import JanusConfigType
from printnanny_api_client.models.login_request import LoginRequest
from printnanny_api_client.models.moonraker_server import MoonrakerServer
from printnanny_api_client.models.moonraker_server_request import MoonrakerServerRequest
from printnanny_api_client.models.nats_organization import NatsOrganization
from printnanny_api_client.models.nats_organization_request import NatsOrganizationRequest
from printnanny_api_client.models.nats_organization_user import NatsOrganizationUser
from printnanny_api_client.models.network_settings import NetworkSettings
from printnanny_api_client.models.network_settings_request import NetworkSettingsRequest
from printnanny_api_client.models.octo_print_backup import OctoPrintBackup
from printnanny_api_client.models.octo_print_server import OctoPrintServer
from printnanny_api_client.models.octo_print_server_request import OctoPrintServerRequest
from printnanny_api_client.models.octo_print_settings import OctoPrintSettings
from printnanny_api_client.models.octo_print_settings_request import OctoPrintSettingsRequest
from printnanny_api_client.models.octo_printer_profile import OctoPrinterProfile
from printnanny_api_client.models.octo_printer_profile_request import OctoPrinterProfileRequest
from printnanny_api_client.models.order import Order
from printnanny_api_client.models.order_checkout import OrderCheckout
from printnanny_api_client.models.order_checkout_request import OrderCheckoutRequest
from printnanny_api_client.models.order_item import OrderItem
from printnanny_api_client.models.order_item_request import OrderItemRequest
from printnanny_api_client.models.order_status import OrderStatus
from printnanny_api_client.models.order_status_type import OrderStatusType
from printnanny_api_client.models.paginated_achievement_list import PaginatedAchievementList
from printnanny_api_client.models.paginated_crash_report_list import PaginatedCrashReportList
from printnanny_api_client.models.paginated_email_alert_settings_list import PaginatedEmailAlertSettingsList
from printnanny_api_client.models.paginated_gcode_file_list import PaginatedGcodeFileList
from printnanny_api_client.models.paginated_moonraker_server_list import PaginatedMoonrakerServerList
from printnanny_api_client.models.paginated_octo_print_backup_list import PaginatedOctoPrintBackupList
from printnanny_api_client.models.paginated_octo_print_server_list import PaginatedOctoPrintServerList
from printnanny_api_client.models.paginated_octo_print_settings_list import PaginatedOctoPrintSettingsList
from printnanny_api_client.models.paginated_octo_printer_profile_list import PaginatedOctoPrinterProfileList
from printnanny_api_client.models.paginated_pi_list import PaginatedPiList
from printnanny_api_client.models.paginated_print_job_alert_list import PaginatedPrintJobAlertList
from printnanny_api_client.models.paginated_product_list import PaginatedProductList
from printnanny_api_client.models.paginated_system_info_list import PaginatedSystemInfoList
from printnanny_api_client.models.paginated_video_recording_list import PaginatedVideoRecordingList
from printnanny_api_client.models.paginated_video_recording_part_list import PaginatedVideoRecordingPartList
from printnanny_api_client.models.paginated_webrtc_stream_list import PaginatedWebrtcStreamList
from printnanny_api_client.models.password_change_request import PasswordChangeRequest
from printnanny_api_client.models.password_reset_confirm_request import PasswordResetConfirmRequest
from printnanny_api_client.models.password_reset_request import PasswordResetRequest
from printnanny_api_client.models.patched_email_alert_settings_request import PatchedEmailAlertSettingsRequest
from printnanny_api_client.models.patched_moonraker_server_request import PatchedMoonrakerServerRequest
from printnanny_api_client.models.patched_network_settings_request import PatchedNetworkSettingsRequest
from printnanny_api_client.models.patched_octo_print_server_request import PatchedOctoPrintServerRequest
from printnanny_api_client.models.patched_octo_print_settings_request import PatchedOctoPrintSettingsRequest
from printnanny_api_client.models.patched_octo_printer_profile_request import PatchedOctoPrinterProfileRequest
from printnanny_api_client.models.patched_pi_request import PatchedPiRequest
from printnanny_api_client.models.patched_system_info_request import PatchedSystemInfoRequest
from printnanny_api_client.models.patched_user_request import PatchedUserRequest
from printnanny_api_client.models.patched_video_recording_request import PatchedVideoRecordingRequest
from printnanny_api_client.models.patched_webrtc_stream_request import PatchedWebrtcStreamRequest
from printnanny_api_client.models.pi import Pi
from printnanny_api_client.models.pi_nats_app import PiNatsApp
from printnanny_api_client.models.pi_nats_app_request import PiNatsAppRequest
from printnanny_api_client.models.pi_request import PiRequest
from printnanny_api_client.models.pi_urls import PiUrls
from printnanny_api_client.models.preferred_dns_type import PreferredDnsType
from printnanny_api_client.models.print_job_alert import PrintJobAlert
from printnanny_api_client.models.product import Product
from printnanny_api_client.models.register_request import RegisterRequest
from printnanny_api_client.models.resend_email_verification_request import ResendEmailVerificationRequest
from printnanny_api_client.models.rest_auth_detail import RestAuthDetail
from printnanny_api_client.models.sbc_enum import SbcEnum
from printnanny_api_client.models.stripe_api_error_code import StripeApiErrorCode
from printnanny_api_client.models.stripe_billing_scheme import StripeBillingScheme
from printnanny_api_client.models.stripe_confirmation_method import StripeConfirmationMethod
from printnanny_api_client.models.stripe_customer_tax_exempt import StripeCustomerTaxExempt
from printnanny_api_client.models.stripe_intent_usage import StripeIntentUsage
from printnanny_api_client.models.stripe_payment_intent_cancellation_reason import StripePaymentIntentCancellationReason
from printnanny_api_client.models.stripe_payment_intent_status import StripePaymentIntentStatus
from printnanny_api_client.models.stripe_price_tiers_mode import StripePriceTiersMode
from printnanny_api_client.models.stripe_price_type import StripePriceType
from printnanny_api_client.models.stripe_product_type import StripeProductType
from printnanny_api_client.models.stripe_session_billing_address_collection import StripeSessionBillingAddressCollection
from printnanny_api_client.models.stripe_session_mode import StripeSessionMode
from printnanny_api_client.models.stripe_source_code_verification_status import StripeSourceCodeVerificationStatus
from printnanny_api_client.models.stripe_submit_type_status import StripeSubmitTypeStatus
from printnanny_api_client.models.system_info import SystemInfo
from printnanny_api_client.models.system_info_request import SystemInfoRequest
from printnanny_api_client.models.token import Token
from printnanny_api_client.models.user import User
from printnanny_api_client.models.user_request import UserRequest
from printnanny_api_client.models.verify_email_request import VerifyEmailRequest
from printnanny_api_client.models.video_recording import VideoRecording
from printnanny_api_client.models.video_recording_part import VideoRecordingPart
from printnanny_api_client.models.video_recording_request import VideoRecordingRequest
from printnanny_api_client.models.webrtc_stream import WebrtcStream
from printnanny_api_client.models.webrtc_stream_request import WebrtcStreamRequest




# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.130.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from printnanny_api_client.api_client import ApiClient
from printnanny_api_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class VideosApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def video_parts_create(self, id, size, buffer_index, buffer_runningtime, file_name, mp4_file, sync_start, video_recording, **kwargs):  # noqa: E501
        """video_parts_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.video_parts_create(id, size, buffer_index, buffer_runningtime, file_name, mp4_file, sync_start, video_recording, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: str
        :param size: (required)
        :type size: int
        :param buffer_index: (required)
        :type buffer_index: int
        :param buffer_runningtime: (required)
        :type buffer_runningtime: int
        :param file_name: (required)
        :type file_name: str
        :param mp4_file: (required)
        :type mp4_file: file
        :param sync_start: (required)
        :type sync_start: datetime
        :param video_recording: (required)
        :type video_recording: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VideoRecordingPart
        """
        kwargs['_return_http_data_only'] = True
        return self.video_parts_create_with_http_info(id, size, buffer_index, buffer_runningtime, file_name, mp4_file, sync_start, video_recording, **kwargs)  # noqa: E501

    def video_parts_create_with_http_info(self, id, size, buffer_index, buffer_runningtime, file_name, mp4_file, sync_start, video_recording, **kwargs):  # noqa: E501
        """video_parts_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.video_parts_create_with_http_info(id, size, buffer_index, buffer_runningtime, file_name, mp4_file, sync_start, video_recording, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: str
        :param size: (required)
        :type size: int
        :param buffer_index: (required)
        :type buffer_index: int
        :param buffer_runningtime: (required)
        :type buffer_runningtime: int
        :param file_name: (required)
        :type file_name: str
        :param mp4_file: (required)
        :type mp4_file: file
        :param sync_start: (required)
        :type sync_start: datetime
        :param video_recording: (required)
        :type video_recording: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(VideoRecordingPart, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id',
            'size',
            'buffer_index',
            'buffer_runningtime',
            'file_name',
            'mp4_file',
            'sync_start',
            'video_recording'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_parts_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `video_parts_create`")  # noqa: E501
        # verify the required parameter 'size' is set
        if self.api_client.client_side_validation and ('size' not in local_var_params or  # noqa: E501
                                                        local_var_params['size'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `size` when calling `video_parts_create`")  # noqa: E501
        # verify the required parameter 'buffer_index' is set
        if self.api_client.client_side_validation and ('buffer_index' not in local_var_params or  # noqa: E501
                                                        local_var_params['buffer_index'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `buffer_index` when calling `video_parts_create`")  # noqa: E501
        # verify the required parameter 'buffer_runningtime' is set
        if self.api_client.client_side_validation and ('buffer_runningtime' not in local_var_params or  # noqa: E501
                                                        local_var_params['buffer_runningtime'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `buffer_runningtime` when calling `video_parts_create`")  # noqa: E501
        # verify the required parameter 'file_name' is set
        if self.api_client.client_side_validation and ('file_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_name` when calling `video_parts_create`")  # noqa: E501
        # verify the required parameter 'mp4_file' is set
        if self.api_client.client_side_validation and ('mp4_file' not in local_var_params or  # noqa: E501
                                                        local_var_params['mp4_file'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mp4_file` when calling `video_parts_create`")  # noqa: E501
        # verify the required parameter 'sync_start' is set
        if self.api_client.client_side_validation and ('sync_start' not in local_var_params or  # noqa: E501
                                                        local_var_params['sync_start'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sync_start` when calling `video_parts_create`")  # noqa: E501
        # verify the required parameter 'video_recording' is set
        if self.api_client.client_side_validation and ('video_recording' not in local_var_params or  # noqa: E501
                                                        local_var_params['video_recording'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `video_recording` when calling `video_parts_create`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['id']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `id` when calling `video_parts_create`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['id']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `id` when calling `video_parts_create`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and 'size' in local_var_params and local_var_params['size'] > 9223372036854775807:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `size` when calling `video_parts_create`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if self.api_client.client_side_validation and 'size' in local_var_params and local_var_params['size'] < -9223372036854775808:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `size` when calling `video_parts_create`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501
        if self.api_client.client_side_validation and 'buffer_index' in local_var_params and local_var_params['buffer_index'] > 9223372036854775807:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `buffer_index` when calling `video_parts_create`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if self.api_client.client_side_validation and 'buffer_index' in local_var_params and local_var_params['buffer_index'] < -9223372036854775808:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `buffer_index` when calling `video_parts_create`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501
        if self.api_client.client_side_validation and 'buffer_runningtime' in local_var_params and local_var_params['buffer_runningtime'] > 9223372036854775807:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `buffer_runningtime` when calling `video_parts_create`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if self.api_client.client_side_validation and 'buffer_runningtime' in local_var_params and local_var_params['buffer_runningtime'] < -9223372036854775808:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `buffer_runningtime` when calling `video_parts_create`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501
        if self.api_client.client_side_validation and ('file_name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['file_name']) > 255):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `file_name` when calling `video_parts_create`, length must be less than or equal to `255`")  # noqa: E501
        if self.api_client.client_side_validation and ('file_name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['file_name']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `file_name` when calling `video_parts_create`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}
        if 'id' in local_var_params:
            form_params.append(('id', local_var_params['id']))  # noqa: E501
        if 'size' in local_var_params:
            form_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'buffer_index' in local_var_params:
            form_params.append(('buffer_index', local_var_params['buffer_index']))  # noqa: E501
        if 'buffer_runningtime' in local_var_params:
            form_params.append(('buffer_runningtime', local_var_params['buffer_runningtime']))  # noqa: E501
        if 'file_name' in local_var_params:
            form_params.append(('file_name', local_var_params['file_name']))  # noqa: E501
        if 'mp4_file' in local_var_params:
            local_var_files['mp4_file'] = local_var_params['mp4_file']  # noqa: E501
        if 'sync_start' in local_var_params:
            form_params.append(('sync_start', local_var_params['sync_start']))  # noqa: E501
        if 'video_recording' in local_var_params:
            form_params.append(('video_recording', local_var_params['video_recording']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data'],
                'POST', body_params))  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            201: "VideoRecordingPart",
            409: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/video-parts/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def video_parts_list(self, **kwargs):  # noqa: E501
        """video_parts_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.video_parts_list(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PaginatedVideoRecordingPartList
        """
        kwargs['_return_http_data_only'] = True
        return self.video_parts_list_with_http_info(**kwargs)  # noqa: E501

    def video_parts_list_with_http_info(self, **kwargs):  # noqa: E501
        """video_parts_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.video_parts_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PaginatedVideoRecordingPartList, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_parts_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "PaginatedVideoRecordingPartList",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/video-parts/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def video_parts_retrieve(self, id, **kwargs):  # noqa: E501
        """video_parts_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.video_parts_retrieve(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique value identifying this video recording part. (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VideoRecordingPart
        """
        kwargs['_return_http_data_only'] = True
        return self.video_parts_retrieve_with_http_info(id, **kwargs)  # noqa: E501

    def video_parts_retrieve_with_http_info(self, id, **kwargs):  # noqa: E501
        """video_parts_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.video_parts_retrieve_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique value identifying this video recording part. (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(VideoRecordingPart, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_parts_retrieve" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `video_parts_retrieve`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "VideoRecordingPart",
            404: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/video-parts/{id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def video_recordings_update_or_create(self, id, **kwargs):  # noqa: E501
        """video_recordings_update_or_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.video_recordings_update_or_create(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this video recording. (required)
        :type id: str
        :param video_recording_request:
        :type video_recording_request: VideoRecordingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VideoRecording
        """
        kwargs['_return_http_data_only'] = True
        return self.video_recordings_update_or_create_with_http_info(id, **kwargs)  # noqa: E501

    def video_recordings_update_or_create_with_http_info(self, id, **kwargs):  # noqa: E501
        """video_recordings_update_or_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.video_recordings_update_or_create_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this video recording. (required)
        :type id: str
        :param video_recording_request:
        :type video_recording_request: VideoRecordingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(VideoRecording, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id',
            'video_recording_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_recordings_update_or_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `video_recordings_update_or_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'video_recording_request' in local_var_params:
            body_params = local_var_params['video_recording_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'],
                'POST', body_params))  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "VideoRecording",
            201: "VideoRecording",
            409: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
            404: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/videos/{id}/update-or-create/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def videos_create(self, **kwargs):  # noqa: E501
        """videos_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_create(async_req=True)
        >>> result = thread.get()

        :param video_recording_request:
        :type video_recording_request: VideoRecordingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VideoRecording
        """
        kwargs['_return_http_data_only'] = True
        return self.videos_create_with_http_info(**kwargs)  # noqa: E501

    def videos_create_with_http_info(self, **kwargs):  # noqa: E501
        """videos_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_create_with_http_info(async_req=True)
        >>> result = thread.get()

        :param video_recording_request:
        :type video_recording_request: VideoRecordingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(VideoRecording, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'video_recording_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method videos_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'video_recording_request' in local_var_params:
            body_params = local_var_params['video_recording_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'],
                'POST', body_params))  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            201: "VideoRecording",
            409: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/videos/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def videos_list(self, **kwargs):  # noqa: E501
        """videos_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_list(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PaginatedVideoRecordingList
        """
        kwargs['_return_http_data_only'] = True
        return self.videos_list_with_http_info(**kwargs)  # noqa: E501

    def videos_list_with_http_info(self, **kwargs):  # noqa: E501
        """videos_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PaginatedVideoRecordingList, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method videos_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "PaginatedVideoRecordingList",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/videos/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def videos_partial_update(self, id, **kwargs):  # noqa: E501
        """videos_partial_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_partial_update(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this video recording. (required)
        :type id: str
        :param patched_video_recording_request:
        :type patched_video_recording_request: PatchedVideoRecordingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VideoRecording
        """
        kwargs['_return_http_data_only'] = True
        return self.videos_partial_update_with_http_info(id, **kwargs)  # noqa: E501

    def videos_partial_update_with_http_info(self, id, **kwargs):  # noqa: E501
        """videos_partial_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_partial_update_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this video recording. (required)
        :type id: str
        :param patched_video_recording_request:
        :type patched_video_recording_request: PatchedVideoRecordingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(VideoRecording, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id',
            'patched_video_recording_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method videos_partial_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `videos_partial_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'patched_video_recording_request' in local_var_params:
            body_params = local_var_params['patched_video_recording_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'],
                'PATCH', body_params))  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            202: "VideoRecording",
            409: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/videos/{id}/', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def videos_retrieve(self, id, **kwargs):  # noqa: E501
        """videos_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_retrieve(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this video recording. (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VideoRecording
        """
        kwargs['_return_http_data_only'] = True
        return self.videos_retrieve_with_http_info(id, **kwargs)  # noqa: E501

    def videos_retrieve_with_http_info(self, id, **kwargs):  # noqa: E501
        """videos_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_retrieve_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this video recording. (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(VideoRecording, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method videos_retrieve" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `videos_retrieve`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "VideoRecording",
            404: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/videos/{id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def videos_update(self, id, **kwargs):  # noqa: E501
        """videos_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_update(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this video recording. (required)
        :type id: str
        :param video_recording_request:
        :type video_recording_request: VideoRecordingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VideoRecording
        """
        kwargs['_return_http_data_only'] = True
        return self.videos_update_with_http_info(id, **kwargs)  # noqa: E501

    def videos_update_with_http_info(self, id, **kwargs):  # noqa: E501
        """videos_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.videos_update_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A UUID string identifying this video recording. (required)
        :type id: str
        :param video_recording_request:
        :type video_recording_request: VideoRecordingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(VideoRecording, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id',
            'video_recording_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method videos_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `videos_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'video_recording_request' in local_var_params:
            body_params = local_var_params['video_recording_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'],
                'PUT', body_params))  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            202: "VideoRecording",
            409: "ErrorDetail",
            400: "ErrorDetail",
            401: "ErrorDetail",
            403: "ErrorDetail",
            500: "ErrorDetail",
        }

        return self.api_client.call_api(
            '/api/videos/{id}/', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
